@@ -1,35 +1,11 @@
-    Mac OS X            	   2  *o     *                                      ATTR      *  L  )U                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Ajulia-config A427R7F42H !R3~v1                                        L
-0t<                    J*;%-<# qq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                  H    ,            
+    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    4  #  com.apple.cs.CodeSignature              t   4                     Ajulia-config A427R7F42H L
+0t<                    J*;%-<#                   H    ,            
 com.apple.env                      julia-config                  
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4                      Ajulia-config A427R7F42H ONvHl_Zt+5b4UEhY2                                                                |ZЂx\lLV~cpKY7,C0                                g]Fq`u.E\&F)Y'	0	*H
+A427R7F42H                4                      Ajulia-config A427R7F42H |ZЂx\lLV~cpKY7,C0                                g]Fq`u.E\&F)Y'	0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -107,50 +83,52 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260106194149Z0/	*H
-	1" R=^MaX3 R#9Pb\3<0[	*Hcd	1N0+Lyb5'֤ %0-	`He U>`O:gr_pVxTp!0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260209210610Z0/	*H
+	1" ^|7eFoոˁw1ϖ&ۥNGخ0[	*Hcd	1N0+x^!j,-0-	`He 
++ǵ)RE ލ.(.,]`$70[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		2Ex5YqvS8zX9urSNJ7G7oNakICU=
+		wnhe8dXLIWqeLJ3d0i3JA+wVwPc=
 		</data>
 		<data>
-		/f5V8z5gDE8aOmdyBp5fn72D9HA=
+		DSvHtSlSEc9FHyDc+t6NLsfb4Qs=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  Jx$`d{ \pY'u0]wLS(r$Xp9:y<C܍$d [ג}0f5:m̠٣{	!-A"zX	fǬz0Y_I2W41|['MFta^TL)sH1T"[
-^?lhz;d-hp>SgSc Nhf)p-oJApfϕ0*H
+  O=ǣ*5e<Wi|̇2J'1N9t0H
+hB/>Yv"ɪX"Zh"-aX
+D+OqWuO#~1H"?̌.aS7	>yԒ,q,6 "pb~hBC^C_K$CG v)X?ǥ)+
+W..u	EVz3Q\]#'MЎѢ?c7 F5&omxס0*H
 	10	*H
-010	+ 0z*H
-	ki0g*010
-	`He  45u
-O.	߷(}8n(eVwG:R|K*Ԇ20260106194150Z0WA!Z_
-00{E0Q;0
+010	+ 0{*H
+	lj0h*010
+	`He  1<־΢W,?)ԌR20260209210610Z0	 @#诵
+00wZ"C0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260105174054Z
-260216174053Z0A10UTimestamp Signer MA110U
+260202174540Z
+260316174539Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
-PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
-ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
+ #6p8̹(B5H^cPGFHZ '@mL@/!c /g
+lZ,Pʹad|-MEGjmsLũ0fheٸ )4_"Fshbrx`˷>OAw֚<P 0X줪 ̷?-M/a*.{,Pu^tzA'Xz۲Vlv@܉a:9 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0g,6t`=Eod0U0
 	*H
-  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
->G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
-މASVO@C]>{6%@nm|?A"00}LWc0
+  +h\`+vq
+(9\9CMvjRu0l c9(O*yd5uTi
+j\CpCŹln*Ja9)GNk2WpՕc_&$!oM_}¯ӵܷ o\(O<'W_9+N˨bc	Ai"TWŐ~w3	1
+@zI(PQLl.JU>00}LWc0
 	*H
  0b10	UUS10U
 
@@ -191,14 +169,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS{E0Q;0	+ 0	*H
+Apple Inc.10	UUSwZ"C0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260106194150Z0#	*H
-	1~Jǩq0+*H
-	10004,yz9_0
+260209210610Z0#	*H
+	1E?4[*~Bbƚ[0+*H
+	1000dldzK#G{:R0
 	*H
-  Z eTEz){3{jШϳQ
-+gԝŊGQQ uHo<)g/A]-=Nv/Q$GoFFQi}ig(85\=l@xEZj {Qp;{1}3־	l[GoKh-:s|oʋw){:^`u\`x{7qm2uL      
\ No newline at end of file
+  0h^~&hݕE&d?Is RjaOrs}<Z;O+Md9M~@@o!'Z?i-P'_
+F+n`6%Θ1T]2Gv䄹qltaRLFg DvqW#@7;wb)8̴;ofRҗp}1k&u>9r      
\ No newline at end of file
