@@ -1,33 +1,9 @@
-    Mac OS X            	   2  *G     *y                                      ATTR      *y  L  )-                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4        ,             Ejuliac-trim-base A427R7F42H !R3~v1                                        3@'\\;̗                    Hzo ضrCIqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            juliac-trim-base                  
+    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      \      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              x   4        ,             Ejuliac-trim-base A427R7F42H 3@'\\;̗                    Hzo ضrCI                            juliac-trim-base                  
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4        ,              Ejuliac-trim-base A427R7F42H ONvHl_Zt+5b4UEhY2                                                                Ƶ
+A427R7F42H                4        ,              Ejuliac-trim-base A427R7F42H Ƶ
 :aI=mކ3 Ug]
 /                                77+9n)]i'PYZ]0	*H
 010
@@ -107,53 +83,52 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260106194149Z0/	*H
-	1" xIO8`0*H ZGd[F0[	*Hcd	1N0+V@(~;+$ZЈ0-	`He <Zb9x8y;Zw3n0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260209210610Z0/	*H
+	1" N`̚Vhq&&Bz?}
+0[	*Hcd	1N0+/ ,UH[]롱0-	`He S)LgZ??j׳A7?i0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		VkDb8ih+Av4UO4+pKySoWsnQiNk=
+		oy8gqyxVC5bqi/tIW3+DXeuhsfs=
 		</data>
 		<data>
-		BjxaiGI5eBH3+g/1s+I4eTv5xFo=
+		Uym8tkxnvFqYFD/azD+5atezQbA=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  L0I'է' 5w7jqF=0uSZn~<AU
-I<6Rm+,ûKG(AWܓ<
-~Jx2_{SG*q+c'oX.F;RNp٨DP@.Z_MɧӁIux%-UF%eKӋD4DCତNi\}xa<&[6H~mfĜx"-ey9GJ?0*H
+  &QL\N4<yN$B8xn9K1	YEysc5OÂ(쾄p|JcIӖ%3owHx|zTGAN%Q+>jh
+;PPA*ӕsltBG.\Ge`7@vXh5)[XM$/_P6P#FOB0Jr߮dD!i4b`UgϨFAˋ :1 YF0*H
 	10	*H
 010	+ 0z*H
 	ki0g*010
-	`He  Vq/y챥5:_N՞`FYYz
-20260106194149Z0zY4	s)
-00;^0
+	`He  &	g`oǕ"Gߎb F=AF5
+320260209210610Z0y4VҠ
+00z*y#0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260105174054Z
-260216174053Z0A10UTimestamp Signer MA210U
+260202174540Z
+260316174539Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- sB#EiLoP
-1ɡ}l
-]oUv3U^A0|
-|S5qToגkH⸨
-7U1w8ςr/-3Y]5&JՌRҸ^c;2)8\l@7c3"
-C׊4]1ҚRjܸ?5JKz c'1UVG g(/2 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U06ގQ?L S00U0
+ hiGH3FfMUd X|tKHZrW4p+jI%:Z9߽Aa4_+=өvp<ygi{ACeiES`Ž00t;̊Q1	CĪ949PVXY#FM^/Sd7/P
+jR;(NvsCB{>qʅIDѬ	a{WW~ʚ
+XXM=21K:|0/X7SGc1 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uci)WsS
+Zi}0U0
 	*H
-  Y3~}uiA2#y
-־9cEF֩$/lT]mkndSܛ}x*f .}FNkVHmJ$W_WiH:vuŏ袒|Vͅus;LV5yYmYyz0[uB~.f!HA$at(nEMOĽ	v5)5fbI<bC'd+H\ϋ00}LWc0
+  ibmڣpŗb]]힆mR5	`4C?T ;NC[p^H63$,&r9krTXCc.'\,?ˇs#)*lLɌ->U	(ѱU"@XѪ^|Lt|YڞFu#tr$192V?KИe<c9
+ٚ٫Edlw,Z/SÝa
+%tne3EFȍ_v@Q @Ffl00}LWc0
 	*H
  0b10	UUS10U
 
@@ -194,20 +169,15 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS;^0	+ 0	*H
+Apple Inc.10	UUSz*y#0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260106194149Z0#	*H
-	1a7]Sv~0+*H
-	1000ةHYfG7 0
+260209210610Z0#	*H
+	1us̥ܟl瘩9;0+*H
+	1000
+cl_B@uLo0
 	*H
-  1|tP$
-f4̦F.4(o|Hv
-[4grv*獕
-OG]PfޞL=~<؁݇'vhw6hD`aRQYHXl3M@\/b
-`
-ۡ);s~__|
-*=MߟA2Baaog9poc&EGڶ"W,ʞoxѽgbN&
-Ӗ      
\ No newline at end of file
+  Ř7&<mw$A.bPhk6C^@Ьh`A;2 aXmchjr׿s}\
+š( }5ӄ`W0Q>>ns2T%W;PN:k9)$?敋SWzJŔ7UtMҢ1	F8{!ȥ`K/N763;*XM!KYl-c&bvQZXU=UV.޽,g      
\ No newline at end of file
