@@ -1,34 +1,9 @@
-    Mac OS X            	   2  *,     *^                                      ATTR      *^  L  )                 L     com.apple.cs.CodeDirectory     
-    com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4        ,             ;juliac A427R7F42H !R3~v1                                        s?Nǁj$)Z%                    (z3|.MKT\Eqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            juliac                    
+    Mac OS X            	   2  &q     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      J      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              n   4        ,             ;juliac A427R7F42H s?Nǁj$)Z%                    (z3|.MKT\E                            juliac                    
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4        ,              ;juliac A427R7F42H ONvHl_Zt+5b4UEhY2                                                                ;ddkJLq}~@Î 漮`ȴ                                [V5ɬ#F;
+A427R7F42H                4        ,              ;juliac A427R7F42H ;ddkJLq}~@Î 漮`ȴ                                [V5ɬ#F;
 +[<zʐL\0	*H
 010
 	`He 0	*H
@@ -107,51 +82,52 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260106194149Z0/	*H
-	1" 0s ܵlL8j&xf0[	*Hcd	1N0+V]7֪"Gq%祛>k0-	`He V\a*0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260209210610Z0/	*H
+	1"  C͟y\4z"R:$P0[	*Hcd	1N0+u->I<IakK0-	`He {,gGQ(RX)D@0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		Vl031qoiA0dxEiW056WbPmsM8oI=
+		dS0+SQeIPAtJYbWX9/QM8/NrnEs=
 		</data>
 		<data>
-		BsHwVr6TXMYT7pvBpwKUvRj26OM=
+		+LDjrtB7LGdHkZf9UZS5GihS59M=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  :Bs*I&?#;]k[xHK3b?'$x4z2
-A2S&>d+Ⱋ
-n]_(!_c1zU("dIliWKqN-\=rʖ0:hB(ܜq]AA>cmN]1Z}itٲ_j}~,C/"^*r[xڽG䩥Oq_	͍A
-d0*H
+  枵o{2Y|bO}8agn׀0袭e7q՜A7
+
+qП,S coR1[S@A^[M5~+?P
+6kÕ>-Ztm'7N'f(<fQ<VMF;g/M⬜B]$@3ƪ~b.BO,!j.@U(z9a/Ba\s]!(EJgeY+@q{Yr~0*H
 	10	*H
 010	+ 0{*H
 	lj0h*010
-	`He  4ՅD,31Bi]#KoPd+4v20260106194151Z0	 Bu`
-00{E0Q;0
+	`He  X	O:Ӆ־~_h!@'8s	20260209210610Z0	 [=
+00z*y#0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260105174054Z
-260216174053Z0A10UTimestamp Signer MA110U
+260202174540Z
+260316174539Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
-PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
-ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
+ hiGH3FfMUd X|tKHZrW4p+jI%:Z9߽Aa4_+=өvp<ygi{ACeiES`Ž00t;̊Q1	CĪ949PVXY#FM^/Sd7/P
+jR;(NvsCB{>qʅIDѬ	a{WW~ʚ
+XXM=21K:|0/X7SGc1 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uci)WsS
+Zi}0U0
 	*H
-  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
->G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
-މASVO@C]>{6%@nm|?A"00}LWc0
+  ibmڣpŗb]]힆mR5	`4C?T ;NC[p^H63$,&r9krTXCc.'\,?ˇs#)*lLɌ->U	(ѱU"@XѪ^|Lt|YڞFu#tr$192V?KИe<c9
+ٚ٫Edlw,Z/SÝa
+%tne3EFȍ_v@Q @Ffl00}LWc0
 	*H
  0b10	UUS10U
 
@@ -192,15 +168,17 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS{E0Q;0	+ 0	*H
+Apple Inc.10	UUSz*y#0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260106194151Z0#	*H
-	1G}ds
-S0+*H
-	10004,yz9_0
+260209210610Z0#	*H
+	1-q>57ٶ0+*H
+	1000
+cl_B@uLo0
 	*H
-  [I~#@EɅ/j?q_cZguMղWiLZ˙ZYqa {ڍg2$Z`~F1ldN
-4%ıLe +7 -ExUp:Z̩\?d%_NZfz:Ty\+}sK-NٯҔj1k2Q5LP`9x]Y5icF y1^T9/WKŊC!  =      
\ No newline at end of file
+  vOEKUW3>ji:,='RJa'&EMOuM,S+U8\i;(o  f,bA,*DX,ܺz
+5+hCIf+wD-
+ăfǆᮖlaNFxUzáqU$^Kt)ư
+Ciibc{ksQK%T8:µω2z U[u)eU0:%7M,X      
\ No newline at end of file
