@@ -1,35 +1,10 @@
-    Mac OS X            	   2  *     *                                      ATTR      *  L  )l                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      
-     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Hmake-fancy-terminfo A427R7F42H !R3~v1                                        s'CwTv                    /sEkqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                  H    ,            
+    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    J  #  com.apple.cs.CodeSignature              {   4                     Hmake-fancy-terminfo A427R7F42H s'CwTv                    /sEk                  H    ,            
 com.apple.env                      make-fancy-terminfo                   
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4                      Hmake-fancy-terminfo A427R7F42H ONvHl_Zt+5b4UEhY2                                                                5+>ӤY7vm,-y                                 ݆TVTNrqnXzbĀ0	*H
+A427R7F42H                4                      Hmake-fancy-terminfo A427R7F42H 5+>ӤY7vm,-y                                 ݆TVTNrqnXzbĀ0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -107,54 +82,51 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260106194149Z0/	*H
-	1" I08li|H<x^[zߡp7HYKu0[	*Hcd	1N0+
-1yrzi\DT0-	`He ߥPdR.)7\1Kj/N4=0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260209210610Z0/	*H
+	1" {cWJjɮWhAF>Dv*	0[	*Hcd	1N0+q7Z.7|0-	`He "%i7%pp+dF
+&/j#vFK0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		CjF5Dh9yj3qc5Glcp+MIRFTil/I=
+		nHGbDoXNHDdanfW2i6guN/wfBHw=
 		</data>
 		<data>
-		36VQZPxS56XOfy4pNxDTXDFLai8=
+		rCIlaTclcHArmWQGHBpGDSbIL/s=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  a'.ƅ[0QH)pb=s8ԵSSJV鳠he,\  z0xǠK<u]xg
-dehTSl?|<S_T,XAvBc|Yۧ8.ǱTlm^JkR
-VZaܛ}#,ރ3#l0؅G>#j:e$L
-؊ۂ[q@` vʎq%=VS0*H
+  u$ua?<WLJRi6@aws4/PN״['{AUk|cd@eWs<[CK#yZ WM;<(#E.
+q_Őm;۸=C"صrl5
+O_'g>5D0?솣a[/FPHIa_uXe٧",Lt+j0*H
 	10	*H
 010	+ 0{*H
 	lj0h*010
-	`He  vgFZ=3"
-h^*ڱv
-iB4-20260106194150Z0	 5ڠ
-00{E0Q;0
+	`He  YTLtHrfגIgwOP2;20260209210612Z0	 km0ݠ
+00wZ"C0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260105174054Z
-260216174053Z0A10UTimestamp Signer MA110U
+260202174540Z
+260316174539Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
-PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
-ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
+ #6p8̹(B5H^cPGFHZ '@mL@/!c /g
+lZ,Pʹad|-MEGjmsLũ0fheٸ )4_"Fshbrx`˷>OAw֚<P 0X줪 ̷?-M/a*.{,Pu^tzA'Xz۲Vlv@܉a:9 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0g,6t`=Eod0U0
 	*H
-  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
->G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
-މASVO@C]>{6%@nm|?A"00}LWc0
+  +h\`+vq
+(9\9CMvjRu0l c9(O*yd5uTi
+j\CpCŹln*Ja9)GNk2WpՕc_&$!oM_}¯ӵܷ o\(O<'W_9+N˨bc	Ai"TWŐ~w3	1
+@zI(PQLl.JU>00}LWc0
 	*H
  0b10	UUS10U
 
@@ -195,17 +167,13 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS{E0Q;0	+ 0	*H
+Apple Inc.10	UUSwZ"C0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260106194150Z0#	*H
-	1<֩8^eE:[j0+*H
-	10004,yz9_0
+260209210612Z0#	*H
+	1\fϩ9/<0+*H
+	1000dldzK#G{:R0
 	*H
-  Ju!LzL:Ee-4W`jAA&ݪ
-h\UJJMϦ@j=Kekc5QRU %/xa͝>$GZΈKiikbxM0,%S8k΀l#wZteIN³	`&TT'0I\
-9r{`u/V3"[[
-KDÕIWDQ.gʌ
-Q{랾1aF9      
\ No newline at end of file
+  OeX~ .w:f!W7ȓ:qޠEՌ>|MWSM`@{WHxvdZ%]2FZ;Vtd'!0jKxKu%*ܩ%!oÓs@SXʖ |	dZ0fR׼^t ٝFsnyH5a?K̰:Fwn/܅M?      
\ No newline at end of file
